
import os
import sys
import numpy as np
import argparse

parser = argparse.ArgumentParser()
parser.add_argument("--fast", help="run without GUI",
                    action="store_true")
args = parser.parse_args()
if args.fast:
    print("Running without GUI")

# """ Import SUMO library """
if 'SUMO_HOME' in os.environ:
    sys.path.append(os.path.join(os.environ['SUMO_HOME'], 'tools'))
    from traci.exceptions import TraCIException
    import traci.constants as tc
    if args.fast:
        import libsumo as traci
    else:
        import traci as traci
else:
    sys.exit("please declare environment variable 'SUMO_HOME'")

sumo_cfg = './scenario_sumo/sumo.cfg.xml'#.format(pathlib.Path(__file__).parent.absolute())

sumo_parameters = ['sumo', '-c', sumo_cfg]

if args.fast:
    traci.start(sumo_parameters)
else:
    traci.init(9999)
# sumoCmd = ['sumo-gui', '-c', sumo_cfg]

# traci.start(sumoCmd)
step = 0

END = 86400.0
NUMBER_OF_VEH = 100
LC_MODE = 1621

GHOST_POS = 750.0
BLOCK_LENGTH = 250.0
BLOCK_LANE = 0

traci.vehicle.add(vehID='ghost', routeID='r0', typeID='ghost', depart=0, departLane=BLOCK_LANE, departPos=GHOST_POS, departSpeed='random', arrivalLane='current', arrivalPos=GHOST_POS)
traci.vehicle.setColor(typeID='ghost',color=(255,0,0))
traci.vehicle.setLength(typeID='ghost',length=BLOCK_LENGTH)

traci.vehicle.setStop(vehID='ghost', edgeID='1f2', pos=GHOST_POS, laneIndex=BLOCK_LANE, duration=10, until=END)# flags=0, startPos=0, until=120)

arrived = 0
MAX_SPEED = 13.89
MAX_DECEL = 9
view_id = 'View #0'

while arrived < NUMBER_OF_VEH:
    print('################ SIM TIME: {} ##################'.format(traci.simulation.getTime()))
    print('################ SIM STEP COUNT: {} ################'.format(step))
    print('\n')
    for vh in traci.vehicle.getIDList():
        if 'ghost' not in vh:
            traci.vehicle.setLaneChangeMode(vh, LC_MODE)
        else:
            continue
    step+=1
    arrived += traci.simulation.getArrivedNumber()
    
    fn = 'screenshots/{}.png'.format(step)
    if traci.gui.hasView(viewID=view_id):
        traci.gui.screenshot(viewID=view_id, filename=fn)
    traci.simulationStep()
traci.close()

# to convert screenshots into a video, cd into the folder and...
# ffmpeg -reinit_filter 0 -start_number 1 -framerate 5 -i %d.png -vf scale=1280:-2 -c:v libx264 -pix_fmt yuv420p out.mp4
